@@ -1,10 +1,10 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-01-05 15:47:13 mtw>
+# Last changed Time-stamp: <2015-01-26 14:07:22 mtw>
 
 package Bio::ViennaNGS::BamStat;
 
-use 5.12.0;
-use version; our $VERSION = qv('0.12_08');
+use 5.10.0;
+use version; our $VERSION = qv('0.12_12');
 use Bio::DB::Sam 1.39;
 use Moose;
 use Carp;
@@ -546,19 +546,42 @@ Bio::ViennaNGS::BamStat - Moose interface to BAM mapping statistics
 
   use Bio::ViennaNGS::BamStat;
 
-  my $bss1 = Bio::ViennaNGS::BamStat->new(bam => "path/to/file.bam");
+  my $bamsummary = Bio::ViennaNGS::BamStatSummary->new(files          => "path/to/file.bam",
+                                                       outpath        => "path/to/output.directory",
+                                                       rlib           => "path/to/R_installation",
+                                                       is_segemehl    =>  0|1,
+                                                       control_match  =>  0|1,
+                                                       control_clip   =>  0|1,
+                                                       control_split  =>  0|1,
+                                                       control_qual   =>  0|1,
+                                                       control_edit   =>  0|1,
+                                                       control_flag   =>  0|1,
+                                                       control_score  =>  0|1,
+                                                      );
 
 =head1 DESCRIPTION
 
 This module provides a L<Moose> interface to the mapping statistics of
-a single BAM file. It builds on L<Bio::DB::Sam> and 
+a single BAM file. It builds on L<Bio::DB::Sam>.
+
+=head1 DEPENDENCIES
+
+=over
+
+=item L<Bio::DB::Sam> >= 1.39
+
+=item L<Moose>
+
+=back
 
 =head1 SEE ALSO
 
-=over 
+=over
 
 =item L<Bio::ViennaNGS>
 
+=item L<Bio::ViennaNGS::BamStatSummary>
+
 =back
 
 =head1 AUTHORS
@@ -573,7 +596,7 @@ a single BAM file. It builds on L<Bio::DB::Sam> and
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 by Michael T. Wolfinger
+Copyright (C) 2015 by Michael T. Wolfinger
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.16.3 or,
