@@ -1,18 +1,15 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2014-12-20 00:34:19 mtw>
+# Last changed Time-stamp: <2015-01-26 01:14:12 mtw>
 
 package Bio::ViennaNGS::Util;
 
 use 5.12.0;
 use Exporter;
-use version; our $VERSION = qv('0.12_07');
+use version; our $VERSION = qv('0.12_11');
 use strict;
 use warnings;
-use Bio::Perl 1.00690001;
-use Bio::DB::Sam 1.39;
 use Data::Dumper;
-use File::Basename qw(basename fileparse);
-use File::Temp qw(tempfile);
+use File::Basename qw(fileparse);
 use IPC::Cmd qw(can_run run);
 use Path::Class;
 use Math::Round;
@@ -22,8 +19,7 @@ use Bio::ViennaNGS::FeatureChain;
 our @ISA = qw(Exporter);
 our @EXPORT = ();
 
-our @EXPORT_OK = qw ( bed_or_bam2bw sortbed bed2bigBed computeTPM
-		      featCount_data parse_multicov write_multicov
+our @EXPORT_OK = qw ( bed_or_bam2bw sortbed bed2bigBed
 		      unique_array kmer_enrichment extend_chain
 		      parse_bed6 fetch_chrom_sizes);
 
@@ -32,17 +28,12 @@ our @EXPORT_OK = qw ( bed_or_bam2bw sortbed bed2bigBed computeTPM
 #^^^^^^^^^^ Variables ^^^^^^^^^^^#
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
 
-our @featCount = ();
 my %unique = ();
 
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
 #^^^^^^^^^^^ Subroutines ^^^^^^^^^^#
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
 
-sub featCount_data {
-  return \@featCount;
-}
-
 sub bed_or_bam2bw {
   my ($type,$infile,$chromsizes,$strand,$dest,$want_norm,$size,$scale,$log) = @_;
   my ($fn_bg_tmp,$fn_bg,$fn_bw);
@@ -167,7 +158,7 @@ sub sortbed {
   my ($cmd,$out);
   my $this_function = (caller(0))[3];
   my $bedtools = can_run('bedtools') or
-    croak "ERROR [$this_function bedtools utility not found";
+    croak "ERROR [$this_function] bedtools utility not found";
 
   croak "ERROR [$this_function] Cannot find $infile"
     unless (-e $infile);
@@ -198,111 +189,6 @@ sub sortbed {
   if (defined $log){ close(LOG); }
 }
 
-sub computeTPM {
-  my ($featCount_sample,$rl) = @_;
-  my ($TPM,$T,$totalTPM) = (0)x3;
-  my ($i,$features,$meanTPM);
-
-  $features = keys %$featCount_sample; # of of features in hash
-  print Dumper(\%$featCount_sample);print ">>$rl<<\n";
-
-  # iterate through $featCount_sample twice:
-  # 1. for computing T (denominator in TPM formula)
-  foreach $i (keys %$featCount_sample){
-    $T += ($$featCount_sample{$i}{count} * $rl)/($$featCount_sample{$i}{len});
-  }
-  # 2. for computng actual TPM values
-  foreach $i (keys %$featCount_sample){
-    $TPM = 1000000 * $$featCount_sample{$i}{count} * $rl/($$featCount_sample{$i}{len} * $T);
-    $$featCount_sample{$i}{TPM} = $TPM;
-    $totalTPM += $TPM;
-  }
-  $meanTPM = $totalTPM/$features;
-  # print "totalTPM=$totalTPM | meanTPM=$meanTPM\n";
-  return $meanTPM;
-}
-
-sub parse_multicov {
-  my ($file) = @_;
-  my @mcData = ();
-  my ($mcSamples,$i);
-  my $this_function = (caller(0))[3];
-
-  croak "ERROR [$this_function] multicov file $file not available\n"
-    unless (-e $file);
-  open (MULTICOV_IN, "< $file") or croak $!;
-
-  while (<MULTICOV_IN>){
-    chomp;
-    @mcData = split(/\t/); # 0:chr|1:start|2:end|3:name|4:score|5:strand
-    $mcSamples = (scalar @mcData)-6; # multicov extends BED6
-    #print "$_\n";
-    for ($i=0;$i<$mcSamples;$i++){
-      $featCount[$i]{$mcData[3]} = {
-				    chr    => $mcData[0],
-				    start  => $mcData[1],
-				    end    => $mcData[2],
-				    name   => $mcData[3],
-				    score  => $mcData[4],
-				    strand => $mcData[5],
-				    len    => eval($mcData[2]-$mcData[1]),
-				    count  => $mcData[eval(6+$i)],
-				   }
-    }
-    #print Dumper(@mcData);
-  }
-  close(MULTICOV_IN);
-  return $mcSamples;
-}
-
-sub write_multicov {
-  my ($item,$dest,$base_name) = @_;
-  my ($outfile,$mcSamples,$nrFeatures,$feat,$i);
-  my $this_function = (caller(0))[3];
-
-  croak "ERROR [$this_function]: $dest does not exist\n"
-    unless (-d $dest);
-  $outfile = file($dest,$base_name.".".$item.".multicov.csv");
-  open (MULTICOV_OUT, "> $outfile") or croak $!;
-
-  $mcSamples = scalar @featCount; # of samples in %{$featCount}
-  $nrFeatures = scalar keys %{$featCount[1]}; # of keys in %{$featCount}[1]
-  #print "=====> write_multicov: writing multicov file $outfile with $nrFeatures lines and $mcSamples conditions\n";
-
-  # check whether each column in %$featCount has the same number of entries
-  for($i=0;$i<$mcSamples;$i++){
-    my $fc = scalar keys %{$featCount[$i]}; # of keys in %{$featCount}
-    #print "condition $i => $fc keys\n";
-    unless($nrFeatures == $fc){
-      croak "ERROR [$this_function]: unequal element count in \%\$featCount\nExpected $nrFeatures have $fc in condition $i\n";
-    }
-  }
-
-  foreach $feat (keys  %{$featCount[1]}){
-    my @mcLine = ();
-    # process standard BED6 fields first
-    push @mcLine, (${$featCount[1]}{$feat}->{chr},
-		   ${$featCount[1]}{$feat}->{start},
-		   ${$featCount[1]}{$feat}->{end},
-		   ${$featCount[1]}{$feat}->{name},
-		   ${$featCount[1]}{$feat}->{score},
-		   ${$featCount[1]}{$feat}->{strand});
-    # process multicov values for all samples
-
-    for($i=0;$i<$mcSamples;$i++){
-     # print "------------>  ";  print "processing $i th condition ";  print "<-----------\n";
-      unless (defined ${$featCount[$i]}{$feat}){
-	croak "Could not find item $feat in mcSample $i\n";
-      }
-      push @mcLine, ${$featCount[$i]}{$feat}->{$item};
-
-    }
-    #print Dumper(\@mcLine);
-    print MULTICOV_OUT join("\t",@mcLine)."\n";
-  }
-  close(MULTICOV_OUT);
-}
-
 sub unique_array{
 
     my $arrayref = shift;
@@ -527,15 +413,6 @@ analysis
   # sort a BED file 
   sortbed($bed_in,$destdir,$bed_out,$rm_orig,$logfile)
 
-  # compute transcript abundance in TPM
-  $meanTPM = computeTPM($sample,$readlength);
-
-  # parse a bedtools multicov compatible file
-  $conds = parse_multicov($infile);
-
-  # write bedtools multicov compatible file
-  write_multicov("TPM",$destdir,$basename);
-
 =head1 DESCRIPTION
 
 Bio::ViennaNGS::Util is a collection of utility subroutines for
@@ -590,7 +467,7 @@ ready.
 
 =item sortbed($infile,$dest,$outfile,$rm_orig,$log)
 
-Sorts BED file C<$infile> with F<bedtools sortt>. C<$dest> and
+Sorts BED file C<$infile> with F<bedtools sort>. C<$dest> and
 C<outfile> name path and filename of the resulting sorted BED
 file. C<$rm_infile> is either 1 or 0 and indicated whether the
 original C<$infile> should be deleted. C<$log> holds path and name of
@@ -602,44 +479,13 @@ Creates an indexed bigBed file from a BED file. C<$infile> is the BED
 file to be transformed, C<$chromsizes> is the chromosome.sizes file
 and C<$dest> contains the output path for results. C<$log> is the name
 of a log file, or undef if no logging is reuqired. A '.bed', '.bed6'
-or '.bed12' suffix in C<$infile> will be replace by '.bb' in the
+or '.bed12' suffix in C<$infile> will be replaced by '.bb' in the
 output. Else, the name of the output bigBed file will be the value of
 C<$infile> plus '.bb' appended.
 
 The conversion from BED to bigBed is done by a third-party utility
-(bedToBigBed), which is executed by IPC::Cmd.
+(bedToBigBed), which is executed by L<IPC::Cmd>.
 
-=item computeTPM($featCount_sample,$rl)
-
-Computes expression in Transcript per Million (TPM) [Wagner
-et.al. Theory Biosci. (2012)]. C<$featCount_sample> is a reference to
-a Hash of Hashes data straucture where keys are feature names and
-values hold a hash that must at least contain length and raw read
-counts. Practically, C<$featCount_sample> is represented by _one_
-element of C<@featCount>, which is populated from a multicov file by
-C<parse_multicov()>. C<$rl> is the read length of the sequencing run.
-
-Returns the mean TPM of the processed sample, which is invariant among
-samples. (TPM models relative molar concentration and thus fulfills
-the invariant average criterion.)
-
-=item parse_multicov($file)
-
-Parse a bedtools multicov (multiBamCov) file, i.e. an extended BED6
-file, into an Array of Hash of Hashes data structure
-(C<@featCount>). C<$file> is the input file. Returns the number of
-samples present in the multicov file, ie. the numner of columns
-extending the canonical BED6 columns in the input multicov file.
-
-=item write_multicov($item,$dest,$base_name)
-
-Write C<@featCount> data to a bedtools multicov (multiBamCov)-type
-file. C<$item> specifies the type of information from C<@featCount>
-HoH entries, e.g. TPM or RPKM. These values must have been computed
-and inserted into C<@featCount> beforehand by
-e.g. C<computeTPM()>. C<$dest> gives the absolute path and
-C<$base_name> the basename (will be extended by C<$item>.csv) of the
-output file.
 
 =back
 
@@ -684,7 +530,7 @@ L<BEDtools|https://github.com/arq5x/bedtools2> on your system.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
+Copyright (C) 2015 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.12.4 or,
